present_sources_for_key

Function present_sources_for_key 

pub fn present_sources_for_key(
    key: &XorName,
    evidence: &KeyVerificationEvidence,
    targets: &VerificationTargets,
) -> Vec<PeerId>
Return peers that gave positive presence evidence for a key.

Only peers in the computed verification target sets are considered.