pub enum BootstrapClaimObservation {
WithinGrace {
first_seen: Instant,
},
PastGrace {
first_seen: Instant,
},
Repeated {
first_seen: Instant,
},
}Expand description
Result of observing a peer’s bootstrap claim.
Variants
WithinGrace
The peer is inside its first and only bootstrap-claim grace window.
PastGrace
The peer has continuously claimed bootstrap status past the grace period.
Repeated
The peer previously stopped claiming bootstrap and then claimed it again.