Module utils

Functions

get_root_dir_and_keypair
The keypair is located inside the root directory. At the same time, when no dir is specified, the dir name is derived from the keypair used in the application: the peer ID is used as the directory name.