Payment quote generation for ant-node.
Generates PaymentQuote values that clients use to pay for data storage.
Compatible with the Autonomi payment system.
NOTE: Quote generation requires integration with the node’s signing capabilities from saorsa-core. This module provides the interface and will be fully integrated when the node is initialized.
Structs
- Quote
Generator - Quote generator for creating payment quotes.
Functions
- verify_
merkle_ candidate_ signature - Verify a
MerklePaymentCandidateNodesignature using ML-DSA-65. - verify_
quote_ content - Verify a payment quote’s content address and ML-DSA-65 signature.
- verify_
quote_ signature - Verify that a payment quote has a valid ML-DSA-65 signature.
- wire_
ml_ dsa_ signer - Wire ML-DSA-65 signing from a node identity into a
QuoteGenerator.