Payment quote generation for ant-node.
Generates PaymentQuote values that clients use to pay for data storage.
Compatible with the Autonomi payment system.
NOTE: Quote generation requires integration with the node’s signing capabilities from saorsa-core. This module provides the interface and will be fully integrated when the node is initialized.
Structs
- Quote
Generator - Quote generator for creating payment quotes.
Functions
- wire_
ml_ dsa_ signer - Wire ML-DSA-65 signing from a node identity into a
QuoteGenerator.