ant_
node
0.4.1
Module utils
Module Items
Functions
In crate ant_
node
ant_node
Module
utils
Functions

get_
root_
dir_
and_
keypair
The keypair is located inside the root directory. At the same time, when no dir is specified, the dir name is derived from the keypair used in the application: the peer ID is used as the directory name.